==> nlcv_0.3.2.tar.gz: nlcv/R/data.R <==
#' @name nlcvRF_R
#' @title nlcv results on random data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a randomly generated dataset.
#' @docType data
#' @usage nlcvRF_R
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_SHS
#' @title nlcv results on strong hetero signal data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a dataset with strong hetero signal.
#' @docType data
#' @usage nlcvRF_SHS
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_SS
#' @title nlcv results on strong signal data a with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a dataset with strong signal.
#' @docType data
#' @usage nlcvRF_SS
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_WHS
#' @title nlcv results on weak signal data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a weak signal dataset.
#' @docType data
#' @usage nlcvRF_WHS
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_WS
#' @title nlcv results on weak hetero signal data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a weak hetero signal dataset.
#' @docType data
#' @usage nlcvRF_WS
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_R
#' @title nlcv results on random data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a randomly generated dataset.
#' @docType data
#' @usage nlcvTT_R
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_SHS
#' @title nlcv results on strong hetero signal data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a dataset with strong hetero signal.
#' @docType data
#' @usage nlcvTT_SHS
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_SS
#' @title nlcv results on strong signal data a with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a dataset with strong signal.
#' @docType data
#' @usage nlcvTT_SS
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_WHS
#' @title nlcv results on weak signal data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a weak signal dataset.
#' @docType data
#' @usage nlcvTT_WHS
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_WS
#' @title nlcv results on weak hetero signal data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a weak hetero signal dataset.
#' @docType data
#' @usage nlcvTT_WS
#' @format \code{nlcv} object
NULL

==> nlcv_0.3.6.tar.gz: nlcv/R/data.R <==
#' @name nlcvRF_R
#' @title nlcv results on random data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a randomly generated dataset.
#' @docType data
#' @usage data(nlcvRF_R)
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_SHS
#' @title nlcv results on strong hetero signal data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a dataset with strong hetero signal.
#' @docType data
#' @usage data(nlcvRF_SHS)
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_SS
#' @title nlcv results on strong signal data a with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a dataset with strong signal.
#' @docType data
#' @usage data(nlcvRF_SS)
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_WHS
#' @title nlcv results on weak signal data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a weak signal dataset.
#' @docType data
#' @usage data(nlcvRF_WHS)
#' @format \code{nlcv} object
NULL

#' @name nlcvRF_WS
#' @title nlcv results on weak hetero signal data with random forest feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with random forest on a weak hetero signal dataset.
#' @docType data
#' @usage data(nlcvRF_WS)
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_R
#' @title nlcv results on random data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a randomly generated dataset.
#' @docType data
#' @usage data(nlcvTT_R)
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_SHS
#' @title nlcv results on strong hetero signal data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a dataset with strong hetero signal.
#' @docType data
#' @usage data(nlcvTT_SHS)
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_SS
#' @title nlcv results on strong signal data a with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a dataset with strong signal.
#' @docType data
#' @usage data(nlcvTT_SS)
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_WHS
#' @title nlcv results on weak signal data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a weak signal dataset.
#' @docType data
#' @usage data(nlcvTT_WHS)
#' @format \code{nlcv} object
NULL

#' @name nlcvTT_WS
#' @title nlcv results on weak hetero signal data with t-test feature selection
#' @description This data set contains the \link{nlcv} results of 
#' selection of features with t-test on a weak hetero signal dataset.
#' @docType data
#' @usage data(nlcvTT_WS)
#' @format \code{nlcv} object
NULL
